@@ -13,7 +13,7 @@
 #' }
 #'
 listOrganisms <- function () {
-    r <- GET("http://rest.colombos.net/", path = "get_organisms")
+    r <- GET("http://rest.colombos.fmach.it/", path = "get_organisms")
     if (r$status_code != 200) {
         stop_for_status(r) # Check the request succeeded
     }
@@ -46,7 +46,7 @@ listOrganisms <- function () {
 #' }
 #'
 listGenes <- function(organism="ecoli") {
-    r <- GET("http://rest.colombos.net/",path = paste("get_genes/",organism, sep=""))
+    r <- GET("http://rest.colombos.fmach.it/",path = paste("get_genes/",organism, sep=""))
     if (r$status_code != 200) {
         stop_for_status(r)    # Check the request succeeded
     }
@@ -82,7 +82,7 @@ listGenes <- function(organism="ecoli") {
 #'
 listContrasts <- function(organism="ecoli"){
     
-    r <- GET("http://rest.colombos.net/",path = paste("get_contrasts/",organism, sep=""))
+    r <- GET("http://rest.colombos.fmach.it/",path = paste("get_contrasts/",organism, sep=""))
     if (r$status_code!= 200) {
         stop_for_status(r)    # Check the request succeeded
         #return(r$headers$statusmessage)
@@ -127,7 +127,7 @@ getCompendium <- function(organism="hpylo", path=NULL){
     if(is.null(path)) path <- getwd() else {}
     destfile <- paste(path,"/",organism, "_compendium_data.zip",sep="")
     if(!file.exists(destfile)){
-        r <- GET("http://rest.colombos.net/",path = paste("get_organism_data/",organism, sep=""))
+        r <- GET("http://rest.colombos.fmach.it/",path = paste("get_organism_data/",organism, sep=""))
         if (r$status_code!= 200) {
             stop_for_status(r)
         } 
@@ -200,7 +200,7 @@ parseCompendium <- function(destfile){
 #'
 listAnnotationTypes <- function(organism="ecoli"){
     
-    r <- GET("http://rest.colombos.net/",path = paste("get_annotation_types/",organism, sep=""))
+    r <- GET("http://rest.colombos.fmach.it/",path = paste("get_annotation_types/",organism, sep=""))
     if (r$status_code!= 200) {
         stop_for_status(r)
     }
@@ -238,7 +238,7 @@ listAnnotationTypes <- function(organism="ecoli"){
 #'
 listEntities <- function(organism="ecoli", annotation="Pathway"){
     if(is.null(annotation)) stop("Insert a string with the annotation type.\n See listAnnotationTypes for the available types.") else {}
-    r <- GET("http://rest.colombos.net/",path = paste("get_entities",organism, gsub(" ","%20", annotation), sep="/"))
+    r <- GET("http://rest.colombos.fmach.it/",path = paste("get_entities",organism, gsub(" ","%20", annotation), sep="/"))
     if (r$status_code!= 200) {
         stop_for_status(r)
     } else {
